module WebFrontendBinect::DocumentBasicHelper
    def count_all_documents(is_appointed)
        all_documents(is_appointed).nil? ? 0 : all_documents(is_appointed).count
    end

    def all_documents(is_appointed)
        if current_user.present?
            Nukleus::Document.all_by_user_id(current_user.id, is_appointed)
        else
            session[:session_id].present? ? Nukleus::Document.all_by_session_id(session[:session_id], is_appointed) : nil
        end
    end

    def price_of_unpaid_documents
        price = 0.0
        all_documents(false).each { |doc| price += doc.price.to_f }
        price
    end

    def count_missing_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, document_version: 0).count - Nukleus::Document.where(user_id: current_user.id, document_version: 1).count
        else
            Nukleus::Document.where(session_id: session[:session_id], document_version: 0).count - Nukleus::Document.where(session_id: session[:session_id], document_version: 1).count
        end
    end

    def count_broken_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :meta_data => { :validation_state => { :pdf_state => { :is_broken => "1" } } }).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :meta_data => { :validation_state => { :pdf_state => { :is_broken => "1" } } }).count
        end
    end

    def count_clean_documents
        if current_user.present?
            Nukleus::Document.where(user_id: current_user.id, :meta_data => { :validation_state => { :pdf_state => { :has_address_data => "1" } } }, :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } }).count
        else
            Nukleus::Document.where(session_id: session[:session_id], :meta_data => { :validation_state => { :pdf_state => { :has_address_data  => "1" } } }, :meta_data => { :validation_state => { :pdf_state => { :has_doc_errors => "1" } } }).count
        end
    end
end
